.. pyTRLCConverter documentation master file, created by
   sphinx-quickstart on Thu Jan 30 11:04:25 2025.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

pyTRLCConverter documentation
=============================

pyTRLCConverter is a command-line tool to convert TRLC files to different output formats, e.g. Markdown or docx.
Since the definition of TRLC types is project-specific, the built-in converters can be extended in an object-oriented manner.

.. uml:: ../../../doc/architecture/context_diagram.puml

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   sw_requirements
   sw_tests
   sw_tracing_report
   coverage_resport
   sw_test_result_report

License information
-------------------
.. toctree::
   :maxdepth: 2

   license_include
